#
# bsdstats-fishing.R, 14 Jan 24
#
# Data from:
#
# https://web.archive.org/web/20080813080244/http://www.bsdstats.org/bt/cpus.html#

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(3)


# Aggregate over each frequency, for a given date
aggregate_day=function(df)
{
total_cpu=sum(df$count)
t=ddply(df, .(frequency), function(X) return(data.frame(count=sum(X$count),
							norm=sum(X$count)/total_cpu)))

return(t)
}


# Totals for each date
total_day=function(df)
{
medians=quantile(rep(df$frequency, df$count), probs=c(0.10, 0.5, 0.90))
t=data.frame(count=sum(df$count),
		max_count=max(df$count),
		mean_count=mean(df$count),
		lm_freq=medians[1],
		mm_freq=medians[2],
		hm_freq=medians[3])

return(t)
}


bsd=read.csv("date-freq-count.csv", as.is=TRUE)

bsd=subset(bsd, frequency != 0) # Remove imperfect extractions

bsd$date=as.Date(as.character(bsd$date), format="%Y%m%d")

# How many cpus in the BSDstats data?
# cat *txt | awk ' {total+=$NF;} ; END {print total;}'
# 3428144
# What fraction of cpus have a Hz count?
sum(bsd$count)/3428144
# [1] 0.6722139

day_info=ddply(bsd, .(date), total_day)

plot(day_info$date, day_info$mm_freq/1e3, col=pal_col[1],
	ylim=c(min(day_info$lm_freq), max(day_info$hm_freq))/1e3,
	xlab="Date", ylab="Frequency (Ghz)")
points(day_info$date, day_info$hm_freq/1e3, col=pal_col[2])
points(day_info$date, day_info$lm_freq/1e3, col=pal_col[3])

legend("bottomright", legend=c("Top 10%", "Median", "Bottom 10%"),
                        fill=pal_col[c(2, 1, 3)], border="white", bty="n", cex=1.3)

dev.copy(dev=png, file="cpu-median-freq-bsd.png")
dev.off()


plot(day_info$date, day_info$count, log="y", col="salmon", cex=1.5,
	xlab="Date", ylab="CPUs")

dev.copy(dev=png, file="cpu-count-bsd.png")
dev.off()



day_agg=ddply(bsd, .(date), aggregate_day)

d_0808_13=subset(day_agg, date == "2008-08-13")
d_1201_30=subset(day_agg, date == "2012-01-30")

plot(d_0808_13$frequency, d_0808_13$count, col=pal_col[1],
	ylim=c(1, 1e3),
	xlab="Frequency", ylab="Occurrences")

points(d_1201_30$frequency, d_1201_30$count, col=pal_col[2])

bsd_mod=glm(frequency ~ date, data=day_agg, weights=count)
bsd_mod=glm(log(frequency) ~ date, data=day_agg, weights=count)
summary(bsd_mod)


